@@ -4,13 +4,23 @@ import logging
 import os
 from glob import glob
 
-from np_lims_tk.core import get_project_name, project_name_to_data_manifestor_template
+from np_lims_tk.core import (
+    get_project_asset,
+    get_project_name,
+    project_name_to_data_manifestor_template,
+    put_project_asset,
+)
 from np_lims_tk.local_paths import path_to_lims_meta
 
-from .dataclasses import LocalComparisonResult, Manifest
+from .dataclasses import LocalComparisonResult, Manifest, Template
 from .exceptions import ManifestError, PathError
 from .paths import generate_path_pattern, resolve_paths
-from .transformers import alt_dict_to_template, dict_to_template, is_alt_format
+from .transformers import (
+    alt_dict_to_template,
+    dict_to_template,
+    dump_Template,
+    is_alt_format,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -104,3 +114,26 @@ def path_to_manifest_template(path: str) -> tuple[Any, tuple[Any, ...]]:
         )
     except Exception as e:
         raise ManifestError("Error parsing manifest") from e
+
+
+data_manifestor_project_asset_name = "data_manifestor_template"
+
+
+def get_project_data_manifestor_template(
+    project_name: str = "default",
+) -> Any:
+    return get_project_asset(
+        project_name,
+        data_manifestor_project_asset_name,
+    )
+
+
+def update_project_data_manifestor_template(
+    project_name: str,
+    template: Template,
+) -> None:
+    put_project_asset(
+        project_name,
+        data_manifestor_project_asset_name,
+        dump_Template(template),
+    )
