@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from typing import List, Tuple, Union
 
 from dataclasses import dataclass, field
 
@@ -16,7 +16,7 @@ class Manifest:
 
     name: str
     template: Template
-    args: tuple[str] = field(default_factory=tuple)
+    args: tuple[str, ...] = field(default_factory=tuple)
     path_patterns: list[str] = field(default_factory=list)
 
 
